Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(118)

Unified Diff: src/compiler/register-allocator.cc

Issue 1031803004: [turbofan] Remove Instruction::IsControl() and Instruction::MarkAsControl() (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/compiler/ppc/instruction-selector-ppc.cc ('k') | src/compiler/x64/instruction-selector-x64.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/register-allocator.cc
diff --git a/src/compiler/register-allocator.cc b/src/compiler/register-allocator.cc
index 9f804e744f1e99d39dede960731753cfa58464c6..0629ecd33c7b4fbcf197c8e13ef3ea1e5691125b 100644
--- a/src/compiler/register-allocator.cc
+++ b/src/compiler/register-allocator.cc
@@ -2444,10 +2444,11 @@ LiveRange* RegisterAllocator::SplitRangeAt(LiveRange* range,
if (pos.Value() <= range->Start().Value()) return range;
// We can't properly connect liveranges if split occured at the end
// of control instruction.
DCHECK(pos.IsInstructionStart() ||
- !InstructionAt(pos.InstructionIndex())->IsControl());
+ (code()->GetInstructionBlock(pos.InstructionIndex()))
+ ->last_instruction_index() != pos.InstructionIndex());
int vreg = GetVirtualRegister();
auto result = LiveRangeFor(vreg);
« no previous file with comments | « src/compiler/ppc/instruction-selector-ppc.cc ('k') | src/compiler/x64/instruction-selector-x64.cc » ('j') | no next file with comments »
@@ -2444,10 +2444,11 @@ LiveRange* RegisterAllocator::SplitRangeAt(LiveRange* range,
if (pos.Value() <= range->Start().Value()) return range;
- // We can't properly connect liveranges if split occured at the end
- // of control instruction.
+ // We can't properly connect liveranges if splitting occurred at the end
+ // a block.
DCHECK(pos.IsInstructionStart() ||

Powered by Google App Engine
This is Rietveld 408576698